@@ -1,11 +1,12 @@
 import os
 
-from behave import step
+from behave import then
+
 from behaving.web.steps.basic import _retry
 
 
-@step(
-    u'the file "{filename}" containing "{text}" should have been downloaded within {timeout:d} seconds'
+@then(
+    'the file "{filename}" containing "{text}" should have been downloaded within {timeout:d} seconds'
 )
 def verify_download_contents(context, filename, text, timeout):
     path = os.path.join(context.download_dir, filename)
@@ -13,18 +14,18 @@ def verify_download_contents(context, filename, text, timeout):
     def check():
         return os.path.exists(path)
 
-    assert _retry(check, timeout), u"File has not been downloaded"
+    assert _retry(check, timeout), f"File {filename} could not be downloaded"
     with open(path, "rb") as f:
         contents = f.read()
 
-    assert text.encode() in contents, u"Text not found in file"
+    assert text.encode() in contents, f'Text "{text}" not found in {filename}'
 
 
-@step(u'the file "{filename}" should have been downloaded within {timeout:d} seconds')
+@then('the file "{filename}" should have been downloaded within {timeout:d} seconds')
 def verify_download(context, filename, timeout):
     path = os.path.join(context.download_dir, filename)
 
     def check():
         return os.path.exists(path)
 
-    assert _retry(check, timeout), u"File has not been downloaded"
+    assert _retry(check, timeout), f"File {filename} has not been downloaded"
